from mcmst_clust import MCMSTClustering, normalize
import numpy as np

# Generate random data
X = np.random.rand(10, 2)
X = normalize(X)

# Initialize and fit the clustering model
model = MCMSTClustering(min_samples=2)
model.fit(X)

# Predict cluster labels
labels = model.predict(X)
print(labels)

